//
//  WRBrowserView.h
//  NSBrowserView
//
//  Created by jadeliquid on Tue Feb 01 2005.
//  Copyright (c) 2005 JadeLiquid Software. All rights reserved.
//

#ifndef __wrCocoaBrowserView_h_
#define __wrCocoaBrowserView_h_

#include "CHBrowserView.h"
#include "nsCOMPtr.h"

class WRClickListener;
class CHKeyListener;
class CHBrowserStream;
class nsIDOMMouseEvent;
class nsIDOMKeyEvent;
class wrmBitmap;
class CHURIListener;

// Add more methods to the CHBrowserListener
@protocol WRBrowserListener <CHBrowserListener>
- (void)onBeforeNavigate:(const char*)url postData:(const char*)postData headers:(const char*)headers targetFrame:(const char*)targetFrame;
- (void)onNetworkState:(unsigned int)flags withStatus:(unsigned long)status andURL:(const char*)url;
- (void)onHTTPResponse:(const char*)headers statusText:(const char*)statusText andStatus:(int)status andRequestHeaders:(const char*)requestOnes;
-(BOOL)onLoadIntercept:(const char*)url;
-(BOOL)onPromptDialog:(int)dialogType withTitle:(NSString*)title andText:(NSString*)text andUsername:(NSMutableString*)username andPassword:(NSMutableString*)password andCheckValue:(BOOL*)checkValue andResult:(int *)bResult;
-(void)onProtocolOpen:(int)listener withURL:(NSString*)URL andChannel:(int)channel andContext:(int) ctxt;
-(BOOL)onHTTPInterceptHeaders:(NSString*)URL andHeaders:(NSString *)headers withModified:(NSMutableString*)modified;
@end

//Progress Flags
enum {
    NS_PROGRESS_FLAG_START = 1,
    NS_PROGRESS_FLAG_REDIRECTING = 2,
    NS_PROGRESS_FLAG_TRANSFERRING = 4,
    NS_PROGRESS_FLAG_NEGOTIATING = 8,
    NS_PROGRESS_FLAG_STOP = 16,

    NS_PROGRESS_FLAG_REQUEST = 65536,
    NS_PROGRESS_FLAG_DOCUMENT = 131072,
    NS_PROGRESS_FLAG_NETWORK = 262144,
    NS_PROGRESS_FLAG_WINDOW = 524288
};

//Network Flags
enum {
    NS_STATUS_FAILED_DNS = 2152398878U,
    NS_STATUS_FAILED_CONNECT = 2152398861U,
    NS_STATUS_FAILED_TIMEOUT = 2152398862U,
    NS_STATUS_FAILED_USERCANCELED = 2152398850U
};

@protocol CHMouseEvent
-(void)onMouseDown:(nsIDOMMouseEvent*)event;
-(void)onMouseUp:(nsIDOMMouseEvent*)event;
-(void)onMouseClick:(nsIDOMMouseEvent*)event;
-(void)onMouseDblClick:(nsIDOMMouseEvent*)event;
//-(void)onCheckBoxChange:(nsIDOMElement*)element isChecked:(bool)isChecked;
//-(void)onRadioSelected:(nsIDOMElement*)element;
//-(void)onButtonClicked:(nsIDOMElement*)element;
@end

@protocol CHKeyEvent
-(void)onKeyPress:(nsIDOMKeyEvent*)event;
-(void)onKeyDown:(nsIDOMKeyEvent*)event;
-(void)onKeyUp:(nsIDOMKeyEvent*)event;
@end



@interface WRBrowserView : CHBrowserViewJL
{
  CHURIListener* _uriListener;
//  nsCOMPtr<nsISupports> _uriListenerGuard;
  
  WRClickListener* clickListener;
  CHKeyListener*   keyListener;

  CHBrowserStream* mStream;
 // nsCOMPtr<nsISupports> mStreamGuard;
  
  BOOL inPreviewMode;
}
-(void)showAbout:(const char*)message;

// CHBrowserView overrides
- (id)initWithFrame:(NSRect)frame;
- (id)initWithFrame:(NSRect)frame andWindow:(NSWindow*)aWindow;
- (void)dealloc;

- (void)addListener:(id <WRBrowserListener>)listener;

// mouse/key listeners
-(void)addMouseListener:(id <CHMouseEvent>)listener;
-(void)addKeyListener:(id <CHKeyEvent>)listener;

- (void)loadURI:(NSString *)urlSpec referrer:(NSString*)referrer flags:(unsigned int)flags postData:(NSString *)postData headers:(NSString *)headers targetFrame:(NSString *)frame;

-(void)openStream:(const char*)aBaseURI withType:(const char*)aContentType;
-(void)appendToStream:(const char*)aData withLength:(long int)aLen;
-(void)closeStream;

- (void)printPreviewMode;

- (void)disableHTTPSDialogs:(int)onOff;

-(void)getTheWebBrowser:(nsIWebBrowser**)aWebBrowser;

-(void)addWRImage:(int) size withData:(wrmBitmap *)bmp;
-(void)setProxyUsername:(NSString*)username andPassword:(NSString*)password;

-(BOOL)FirePromptDialog:(int)dialogType withTitle:(NSString*)title andText:(NSString*)text andUsername:(NSMutableString*)username andPassword:(NSMutableString*)password andCheckValue:(BOOL*)checkValue andResult:(int *)bResult;
-(BOOL)FireHTTPInterceptHeaders:(NSString*)URL andHeaders:(NSString *)headers withModified:(NSMutableString*)modified;
-(BOOL)FireHTTPResponse:(const char*)headers statusText:(const char*)statusText andStatus:(int)status andRequestHeaders:(const char*)requestOnes;

//CustomProtocolStuff
-(void)registerProtocol:(NSString*)protocolName;
-(void)protocolOnStart:(int)channel withContentType:(NSString*)contentType;
-(void)protocolOnData:(int)channel withData:(NSData*)data;
-(void)protocolOnStop:(int)channel withResult:(int)result;
-(void)FireOnProtocolOpen:(int)listener withURL:(NSString*)URL andChannel:(int)channel andContext:(int)ctxt;

-(void)setHttpResponseAll:(BOOL)setting;
-(BOOL)getHttpResponseAll;

- (BOOL)findInPageWithPattern:(NSString*)inText caseSensitive:(BOOL)inCaseSensitive
            wrap:(BOOL)inWrap backwards:(BOOL)inBackwards wholeWord:(BOOL)ww;
			
//Window Delegate
-(NSSize)windowWillResize:(NSWindow *)sender toSize:(NSSize)proposedFrameSize;
@end

//Initialize embedding with given appDir
extern void initEmbedding(const char*binAppDir);
extern void setProfilePath(const char*profilePath);

#endif //__wrCocoaBrowserView_h_